
from urllib.parse import urlencode

from django.urls import reverse_lazy
from django.contrib import admin
from django.contrib import messages
from django.shortcuts import render, redirect
from django.utils.translation import ugettext_lazy as _

from product_barcode.models import BarCode


@admin.register(BarCode)
class BarCodeAdmin(admin.ModelAdmin):

    def has_add_permission(self, request):
        return False

    def has_delete_permission(self, request, obj=None):
        return False


@admin.site.register_view(
    'barcode/generate/',
    _('Generate bar codes'),
    'generate-bar-codes')
def generate_codes(request):

    context = admin.site.each_context(request)

    if request.method == 'POST':
        try:
            count = int(request.POST['count'])
            codes = BarCode.get_solo().get_next_codes(count)
            url = reverse_lazy('barcode:print')
            url += '?' + urlencode({'codes': ','.join(map(str, codes))})
        except Exception:
            messages.error(request, _('Incorrect number'))
            url = request.path

        return redirect(url)

    return render(request, 'barcode/generate.html', context)



# Generated by Django 2.0.13 on 2020-03-04 13:01

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='BarCode',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('next_code', models.IntegerField(blank=True, default=1, null=True, verbose_name='Next bar code')),
            ],
            options={
                'verbose_name': 'Bar code',
                'verbose_name_plural': 'Bar codes',
            },
        ),
    ]




class BarCodeSettings(object):

    @property
    def INSTALLED_APPS(self):
        apps = super().INSTALLED_APPS + ['product_barcode']

        if not 'solo' in apps:
            apps.append('solo')

        return apps


default = BarCodeSettings
